@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from .app import GKola
+__version__ = '0.1.6'
+
+from .app import Kola
 from .blueprint import Blueprint
\ No newline at end of file
