@@ -4,7 +4,7 @@ import json
 import kola.connection
 from kola.utils import safe_call
 
-from .vals import logger
+from kola.vals import logger
 
 
 class Connection(kola.connection.Connection):
